@@ -12,10 +12,10 @@ def parse_features(features: str) -> frozenset[FeatureFlag]:
     """Parse features env var
 
     Args:
-        features (str): Comma separated feature flags
+        features: Comma separated feature flags
 
     Returns:
-        frozenset[FeatureFlag]: A frozen set of known features.
+        A frozen set of known features.
     """
 
     features_set = frozenset(
