@@ -10,6 +10,7 @@ from rich.style import Style
 
 from ._cache import FIFOCache
 from ._filter import LineFilter
+from ._segment_tools import index_to_cell_position
 
 
 @rich.repr.auto
@@ -19,8 +20,8 @@ class Strip:
     A Strip is like an immutable list of Segments. The immutability allows for effective caching.
 
     Args:
-        segments (Iterable[Segment]): An iterable of segments.
-        cell_length (int | None, optional): The cell length if known, or None to calculate on demand. Defaults to None.
+        segments: An iterable of segments.
+        cell_length: The cell length if known, or None to calculate on demand. Defaults to None.
     """
 
     __slots__ = [
@@ -47,27 +48,42 @@ class Strip:
         """Create a blank strip.
 
         Args:
-            cell_length (int): Desired cell length.
-            style (Style | None): Style of blank.
+            cell_length: Desired cell length.
+            style: Style of blank.
 
         Returns:
-            Strip: New strip.
+            New strip.
         """
         return cls([Segment(" " * cell_length, style)], cell_length)
 
     @classmethod
-    def from_lines(cls, lines: list[list[Segment]], cell_length: int) -> list[Strip]:
+    def from_lines(
+        cls, lines: list[list[Segment]], cell_length: int | None = None
+    ) -> list[Strip]:
         """Convert lines (lists of segments) to a list of Strips.
 
         Args:
-            lines (list[list[Segment]]): List of lines, where a line is a list of segments.
-            cell_length (int): Cell length of lines (must be same).
+            lines: List of lines, where a line is a list of segments.
+            cell_length: Cell length of lines (must be same) or None if not known. Defaults to None.
 
         Returns:
-            list[Strip]: List of strips.
+            List of strips.
         """
         return [cls(segments, cell_length) for segments in lines]
 
+    def index_to_cell_position(self, index: int) -> int:
+        """Given a character index, return the cell position of that character.
+        This is the sum of the cell lengths of all the characters *before* the character
+        at `index`.
+
+        Args:
+            index: The index to convert.
+
+        Returns:
+            The cell position of the character at `index`.
+        """
+        return index_to_cell_position(self._segments, index)
+
     @property
     def cell_length(self) -> int:
         """Get the number of cells required to render this object."""
@@ -81,10 +97,10 @@ class Strip:
         """Join a number of strips in to one.
 
         Args:
-            strips (Iterable[Strip]): An iterable of Strips.
+            strips: An iterable of Strips.
 
         Returns:
-            Strip: A new combined strip.
+            A new combined strip.
         """
 
         segments: list[list[Segment]] = []
@@ -109,8 +125,8 @@ class Strip:
     def __len__(self) -> int:
         return len(self._segments)
 
-    def __eq__(self, strip: Strip) -> bool:
-        return (
+    def __eq__(self, strip: object) -> bool:
+        return isinstance(strip, Strip) and (
             self._segments == strip._segments and self.cell_length == strip.cell_length
         )
 
@@ -118,11 +134,11 @@ class Strip:
         """Adjust the cell length, possibly truncating or extending.
 
         Args:
-            cell_length (int): New desired cell length.
-            style (Style | None): Style when extending, or `None`. Defaults to `None`.
+            cell_length: New desired cell length.
+            style: Style when extending, or `None`. Defaults to `None`.
 
         Returns:
-            Strip: A new strip with the supplied cell length.
+            A new strip with the supplied cell length.
         """
 
         new_line: list[Segment]
@@ -162,7 +178,7 @@ class Strip:
         """Simplify the segments (join segments with same style)
 
         Returns:
-            Strip: New strip.
+            New strip.
         """
         line = Strip(
             Segment.simplify(self._segments),
@@ -174,10 +190,10 @@ class Strip:
         """Apply a filter to all segments in the strip.
 
         Args:
-            filter (LineFilter): A line filter object.
+            filter: A line filter object.
 
         Returns:
-            Strip: A new Strip.
+            A new Strip.
         """
         return Strip(filter.apply(self._segments), self._cell_length)
 
@@ -185,11 +201,11 @@ class Strip:
         """Apply a style to Segments with the given link_id.
 
         Args:
-            link_id (str): A link id.
-            link_style (Style): Style to apply.
+            link_id: A link id.
+            link_style: Style to apply.
 
         Returns:
-            Strip: New strip (or same Strip if no changes).
+            New strip (or same Strip if no changes).
         """
         _Segment = Segment
         if not any(
@@ -214,11 +230,11 @@ class Strip:
         """Crop a strip between two cell positions.
 
         Args:
-            start (int): The start cell position (inclusive).
-            end (int): The end cell position (exclusive).
+            start: The start cell position (inclusive).
+            end: The end cell position (exclusive).
 
         Returns:
-            Strip: A new Strip.
+            A new Strip.
         """
         if start == 0 and end == self.cell_length:
             return self
@@ -267,10 +283,10 @@ class Strip:
         """Divide the strip in to multiple smaller strips by cutting at given (cell) indices.
 
         Args:
-            cuts (Iterable[int]): An iterable of cell positions as ints.
+            cuts: An iterable of cell positions as ints.
 
         Returns:
-            list[Strip]: A new list of strips.
+            A new list of strips.
         """
 
         pos = 0
