@@ -4,16 +4,16 @@ from dataclasses import dataclass
 from typing import ClassVar, Generic, NewType, TypeVar
 
 import rich.repr
-from rich.segment import Segment
 from rich.style import NULL_STYLE, Style
 from rich.text import Text, TextType
 
 from .. import events
 from .._cache import LRUCache
 from .._loop import loop_last
-from .._segment_tools import line_crop, line_pad
+from .._segment_tools import line_pad
 from .._types import MessageTarget
 from .._typing import TypeAlias
+from .._immutable_sequence_view import ImmutableSequenceView
 from ..binding import Binding
 from ..geometry import Region, Size, clamp
 from ..message import Message
@@ -31,12 +31,12 @@ TOGGLE_STYLE = Style.from_meta({"toggle": True})
 
 
 @dataclass
-class _TreeLine:
-    path: list[TreeNode]
+class _TreeLine(Generic[TreeDataType]):
+    path: list[TreeNode[TreeDataType]]
     last: bool
 
     @property
-    def node(self) -> TreeNode:
+    def node(self) -> TreeNode[TreeDataType]:
         """TreeNode: The node associated with this line."""
         return self.path[-1]
 
@@ -44,15 +44,19 @@ class _TreeLine:
         """Get the cell width of the line as rendered.
 
         Args:
-            guide_depth (int): The guide depth (cells in the indentation).
+            guide_depth: The guide depth (cells in the indentation).
 
         Returns:
-            int: Width in cells.
+            Width in cells.
         """
         guides = max(0, len(self.path) - (1 if show_root else 2)) * guide_depth
         return guides
 
 
+class TreeNodes(ImmutableSequenceView["TreeNode[TreeDataType]"]):
+    """An immutable collection of `TreeNode`."""
+
+
 @rich.repr.auto
 class TreeNode(Generic[TreeDataType]):
     """An object that represents a "node" in a tree control."""
@@ -71,10 +75,10 @@ class TreeNode(Generic[TreeDataType]):
         self._tree = tree
         self._parent = parent
         self._id = id
-        self._label = label
+        self._label = tree.process_label(label)
         self.data = data
         self._expanded = expanded
-        self._children: list[TreeNode] = []
+        self._children: list[TreeNode[TreeDataType]] = []
 
         self._hover_ = False
         self._selected_ = False
@@ -91,6 +95,11 @@ class TreeNode(Generic[TreeDataType]):
         self._selected_ = False
         self._updates += 1
 
+    @property
+    def children(self) -> TreeNodes[TreeDataType]:
+        """TreeNodes[TreeDataType]: The child nodes of a TreeNode."""
+        return TreeNodes(self._children)
+
     @property
     def line(self) -> int:
         """int: Get the line number for this node, or -1 if it is not displayed."""
@@ -121,6 +130,11 @@ class TreeNode(Generic[TreeDataType]):
         """NodeID: Get the node ID."""
         return self._id
 
+    @property
+    def parent(self) -> TreeNode[TreeDataType] | None:
+        """TreeNode[TreeDataType] | None: The parent of the node."""
+        return self._parent
+
     @property
     def is_expanded(self) -> bool:
         """bool: Check if the node is expanded."""
@@ -163,11 +177,20 @@ class TreeNode(Generic[TreeDataType]):
         self._updates += 1
         self._tree._invalidate()
 
+    @property
+    def label(self) -> TextType:
+        """TextType: The label for the node."""
+        return self._label
+
+    @label.setter
+    def label(self, new_label: TextType) -> None:
+        self.set_label(new_label)
+
     def set_label(self, label: TextType) -> None:
         """Set a new label for the node.
 
         Args:
-            label (TextType): A str or Text object with the new label.
+            label: A str or Text object with the new label.
         """
         self._updates += 1
         text_label = self._tree.process_label(label)
@@ -184,13 +207,13 @@ class TreeNode(Generic[TreeDataType]):
         """Add a node to the sub-tree.
 
         Args:
-            label (TextType): The new node's label.
-            data (TreeDataType): Data associated with the new node.
-            expand (bool, optional): Node should be expanded. Defaults to True.
-            allow_expand (bool, optional): Allow use to expand the node via keyboard or mouse. Defaults to True.
+            label: The new node's label.
+            data: Data associated with the new node.
+            expand: Node should be expanded. Defaults to True.
+            allow_expand: Allow use to expand the node via keyboard or mouse. Defaults to True.
 
         Returns:
-            TreeNode[TreeDataType]: A new Tree node
+            A new Tree node
         """
         text_label = self._tree.process_label(label)
         node = self._tree._add_node(self, text_label, data)
@@ -207,11 +230,11 @@ class TreeNode(Generic[TreeDataType]):
         """Add a 'leaf' node (a node that can not expand).
 
         Args:
-            label (TextType): Label for the node.
-            data (TreeDataType | None, optional): Optional data. Defaults to None.
+            label: Label for the node.
+            data: Optional data. Defaults to None.
 
         Returns:
-            TreeNode[TreeDataType]: New node.
+            New node.
         """
         node = self.add(label, data, expand=False, allow_expand=False)
         return node
@@ -311,39 +334,52 @@ class Tree(Generic[TreeDataType], ScrollView, can_focus=True):
         """Event sent when a node is selected.
 
         Attributes:
-            TreeNode[EventTreeDataType]: The node that was selected.
+            node: The node that was selected.
         """
 
         def __init__(
             self, sender: MessageTarget, node: TreeNode[EventTreeDataType]
         ) -> None:
-            self.node = node
+            self.node: TreeNode[EventTreeDataType] = node
             super().__init__(sender)
 
     class NodeExpanded(Generic[EventTreeDataType], Message, bubble=True):
         """Event sent when a node is expanded.
 
         Attributes:
-            TreeNode[EventTreeDataType]: The node that was expanded.
+            node: The node that was expanded.
         """
 
         def __init__(
             self, sender: MessageTarget, node: TreeNode[EventTreeDataType]
         ) -> None:
-            self.node = node
+            self.node: TreeNode[EventTreeDataType] = node
             super().__init__(sender)
 
     class NodeCollapsed(Generic[EventTreeDataType], Message, bubble=True):
         """Event sent when a node is collapsed.
 
         Attributes:
-            TreeNode[EventTreeDataType]: The node that was collapsed.
+            node: The node that was collapsed.
         """
 
         def __init__(
             self, sender: MessageTarget, node: TreeNode[EventTreeDataType]
         ) -> None:
-            self.node = node
+            self.node: TreeNode[EventTreeDataType] = node
+            super().__init__(sender)
+
+    class NodeHighlighted(Generic[EventTreeDataType], Message, bubble=True):
+        """Event sent when a node is highlighted.
+
+        Attributes:
+            node: The node that was highlighted.
+        """
+
+        def __init__(
+            self, sender: MessageTarget, node: TreeNode[EventTreeDataType]
+        ) -> None:
+            self.node: TreeNode[EventTreeDataType] = node
             super().__init__(sender)
 
     def __init__(
@@ -382,10 +418,10 @@ class Tree(Generic[TreeDataType], ScrollView, can_focus=True):
         """Process a str or Text in to a label. Maybe overridden in a subclass to change modify how labels are rendered.
 
         Args:
-            label (TextType): Label.
+            label: Label.
 
         Returns:
-            Text: A Rich Text object.
+            A Rich Text object.
         """
         if isinstance(label, str):
             text_label = Text.from_markup(label)
@@ -412,12 +448,12 @@ class Tree(Generic[TreeDataType], ScrollView, can_focus=True):
         """Render a label for the given node. Override this to modify how labels are rendered.
 
         Args:
-            node (TreeNode[TreeDataType]): A tree node.
-            base_style (Style): The base style of the widget.
-            style (Style): The additional style for the label.
+            node: A tree node.
+            base_style: The base style of the widget.
+            style: The additional style for the label.
 
         Returns:
-            Text: A Rich Text object containing the label.
+            A Rich Text object containing the label.
         """
         node_label = node._label.copy()
         node_label.stylize(style)
@@ -440,10 +476,10 @@ class Tree(Generic[TreeDataType], ScrollView, can_focus=True):
         overridden in a sub-class if it can be done more efficiently.
 
         Args:
-            node (TreeNode[TreeDataType]): A node.
+            node: A node.
 
         Returns:
-            int: Width in cells.
+            Width in cells.
         """
         label = self.render_label(node, NULL_STYLE, NULL_STYLE)
         return label.cell_len
@@ -466,11 +502,11 @@ class Tree(Generic[TreeDataType], ScrollView, can_focus=True):
         self._updates += 1
         self.refresh()
 
-    def select_node(self, node: TreeNode | None) -> None:
+    def select_node(self, node: TreeNode[TreeDataType] | None) -> None:
         """Move the cursor to the given node, or reset cursor.
 
         Args:
-            node (TreeNode | None): A tree node, or None to reset cursor.
+            node: A tree node, or None to reset cursor.
         """
         self.cursor_line = -1 if node is None else node._line
 
@@ -478,10 +514,10 @@ class Tree(Generic[TreeDataType], ScrollView, can_focus=True):
         """Get the node for a given line.
 
         Args:
-            line_no (int): A line number.
+            line_no: A line number.
 
         Returns:
-            TreeNode[TreeDataType] | None: A tree node, or ``None`` if there is no node at that line.
+            A tree node, or ``None`` if there is no node at that line.
         """
         try:
             line = self._tree_lines[line_no]
@@ -490,6 +526,26 @@ class Tree(Generic[TreeDataType], ScrollView, can_focus=True):
         else:
             return line.node
 
+    class UnknownNodeID(Exception):
+        """Exception raised when referring to an unknown `TreeNode` ID."""
+
+    def get_node_by_id(self, node_id: NodeID) -> TreeNode[TreeDataType]:
+        """Get a tree node by its ID.
+
+        Args:
+            node_id: The ID of the node to get.
+
+        Returns:
+            The node associated with that ID.
+
+        Raises:
+            Tree.UnknownID: Raised if the `TreeNode` ID is unknown.
+        """
+        try:
+            return self._nodes[node_id]
+        except KeyError:
+            raise self.UnknownNodeID(f"Unknown NodeID ({node_id}) in tree") from None
+
     def validate_cursor_line(self, value: int) -> int:
         """Prevent cursor line from going outside of range."""
         return clamp(value, 0, len(self._tree_lines) - 1)
@@ -517,7 +573,7 @@ class Tree(Generic[TreeDataType], ScrollView, can_focus=True):
         """Create a new node ID.
 
         Returns:
-            NodeID: A unique node ID.
+            A unique node ID.
         """
         id = self._current_id
         self._current_id += 1
@@ -531,6 +587,27 @@ class Tree(Generic[TreeDataType], ScrollView, can_focus=True):
         else:
             return tree_line.node
 
+    def _get_label_region(self, line: int) -> Region | None:
+        """Returns the region occupied by the label of the node at line `line`.
+
+        This can be used, e.g., when scrolling to that line such that the label
+        is visible after the scroll.
+
+        Args:
+            line: A line number.
+
+        Returns:
+            The region occupied by the label, or `None` if the
+            line is not in the tree.
+        """
+        try:
+            tree_line = self._tree_lines[line]
+        except IndexError:
+            return None
+        region_x = tree_line._get_guide_width(self.guide_depth, self.show_root)
+        region_width = self.get_label_width(tree_line.node)
+        return Region(region_x, line, region_width, 1)
+
     def watch_hover_line(self, previous_hover_line: int, hover_line: int) -> None:
         previous_node = self._get_node(previous_hover_line)
         if previous_node is not None:
@@ -554,6 +631,8 @@ class Tree(Generic[TreeDataType], ScrollView, can_focus=True):
             self._refresh_node(node)
             node._selected = True
             self._cursor_node = node
+            if previous_node != node:
+                self.post_message_no_wait(self.NodeHighlighted(self, node))
 
     def watch_guide_depth(self, guide_depth: int) -> None:
         self._invalidate()
@@ -566,15 +645,17 @@ class Tree(Generic[TreeDataType], ScrollView, can_focus=True):
         """Scroll to the given line.
 
         Args:
-            line (int): A line number.
+            line: A line number.
         """
-        self.scroll_to_region(Region(0, line, self.size.width, 1))
+        region = self._get_label_region(line)
+        if region is not None:
+            self.scroll_to_region(region)
 
-    def scroll_to_node(self, node: TreeNode) -> None:
+    def scroll_to_node(self, node: TreeNode[TreeDataType]) -> None:
         """Scroll to the given node.
 
         Args:
-            node (TreeNode): Node to scroll in to view.
+            node: Node to scroll in to view.
         """
         line = node._line
         if line != -1:
@@ -584,7 +665,7 @@ class Tree(Generic[TreeDataType], ScrollView, can_focus=True):
         """Refresh (repaint) a given line in the tree.
 
         Args:
-            line (int): Line number.
+            line: Line number.
         """
         region = Region(0, line - self.scroll_offset.y, self.size.width, 1)
         self.refresh(region)
@@ -598,7 +679,7 @@ class Tree(Generic[TreeDataType], ScrollView, can_focus=True):
         """Refresh a node and all its children.
 
         Args:
-            node (TreeNode[TreeDataType]): A tree node.
+            node: A tree node.
         """
         scroll_y = self.scroll_offset.y
         height = self.size.height
@@ -628,7 +709,9 @@ class Tree(Generic[TreeDataType], ScrollView, can_focus=True):
 
         root = self.root
 
-        def add_node(path: list[TreeNode], node: TreeNode, last: bool) -> None:
+        def add_node(
+            path: list[TreeNode[TreeDataType]], node: TreeNode[TreeDataType], last: bool
+        ) -> None:
             child_path = [*path, node]
             node._line = len(lines)
             add_line(TreeLine(child_path, last))
@@ -715,10 +798,10 @@ class Tree(Generic[TreeDataType], ScrollView, can_focus=True):
                 """Get the guide strings for a given style.
 
                 Args:
-                    style (Style): A Style object.
+                    style: A Style object.
 
                 Returns:
-                    tuple[str, str, str, str]: Strings for space, vertical, terminator and cross.
+                    Strings for space, vertical, terminator and cross.
                 """
                 if self.show_guides:
                     lines = self.LINES["default"]
